@@ -1,11 +1,10 @@
 package Paginator::Lite;
-
+$Paginator::Lite::VERSION = '2.001000';
 use strict;
 use warnings;
 
 use Moo;
-
-our $VERSION = '2.000007';
+use URI;
 
 has curr => (
     required => 1,
@@ -37,6 +36,15 @@ has base_url => (
     isa      => sub { die "base_url must be defined" unless defined $_[0] },
 );
 
+has mode => (
+    is      => 'ro',
+    default => sub { 'path' },
+    isa     => sub {
+        my $mode = shift;
+        die "mode must be 'path' or 'query'" unless $mode =~ /path|query/;
+    },
+);
+
 has first => ( is => 'ro' );
 
 has prev => ( is => 'ro' );
@@ -85,6 +93,29 @@ sub BUILD {
     }
 }
 
+sub first_url { $_[0]->_custom_url( $_[0]->first ) }
+sub prev_url  { $_[0]->_custom_url( $_[0]->prev ) }
+sub curr_url  { $_[0]->_custom_url( $_[0]->curr ) }
+sub next_url  { $_[0]->_custom_url( $_[0]->next ) }
+sub last_url  { $_[0]->_custom_url( $_[0]->last ) }
+sub page_url  { $_[0]->_custom_url( $_[1] ) }
+
+sub _custom_url {
+    my ( $self, $page ) = @_;
+
+    my $uri = URI->new( $self->base_url );
+
+    if ( $self->mode eq 'path' ) {
+        return $uri->path . '/' . $page;
+    }
+    else {
+        my $params = $self->params;
+        $params->{page} = $page;
+        $uri->query_form($params);
+        return $uri->as_string;
+    }
+}
+
 sub _ceil {
     my ( $val, $floor ) = @_;
 
@@ -95,17 +126,19 @@ sub _ceil {
 
 return 42;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Paginator::Lite - A simple paginator
-
+Paginator::Lite
 
 =head1 VERSION
 
-2.0.7
-
+version 2.001000
 
 =head1 SYNOPSIS
 
@@ -119,6 +152,10 @@ A simple tool to automate the creation of paging links
         frame_size  => 5,
         page_size   => 10, 
         base_url    => '/foo/items',
+        mode        => 'query',
+        params      => {
+            bar => 123
+        },
     });
     
     ...
@@ -130,7 +167,12 @@ A simple tool to automate the creation of paging links
     $paginator->next        # 4
     $paginator->prev        # 2
     $paginator->base_url    # '/foo/items'
-    
+
+    $paginator->first_url   # '/foo/items?bar=123&page=1'
+    $paginator->prev_url    # '/foo/items?bar=123&page=2'
+    $paginator->curr_url    # '/foo/items?bar=123&page=3'
+    $paginator->next_url    # '/foo/items?bar=123&page=4'
+    $paginator->last_url    # '/foo/items?bar=123&page=7'
 
 =head1 DESCRIPTION
 
@@ -156,6 +198,14 @@ and other permanent buttons:
               ----- frame ----
                 7 of 21 pages
 
+=head1 NAME
+
+Paginator::Lite - A simple paginator
+
+=head1 VERSION
+
+2.1.0
+
 =head1 METHODS
 
 =head2 new
@@ -170,7 +220,6 @@ C<params> is a optional argument that may be used to pass arbitrary data.
 See more details about them in documentation of their respective
 accessors.
 
-
 =head2 base_url
 
 Returns the value of C<base_url>. It is the same value that you must supply
@@ -205,7 +254,6 @@ single page.
 Returns the value of C<items>. It is the same value the you must provide to
 constructor and means the total number of items that you are paginating.
 
-
 =head2 first
 
 Returns the value of the first page, usually B<1>.
@@ -242,16 +290,42 @@ when current page is C<last>.
 
 Returns arbitrary data passed to contructor by C<params> argument.
 
+=head2 mode
+
+Returns the chosen mode (path or query) of resulting URLs.
+
+=head2 first_url
+
+Returns the URL of the first page.
+
+=head2 prev_url
+
+Returns the URL of the previous page.
+
+=head2 curr_url
+
+Returns the URL of the current page.
+
+=head2 next_url
+
+Returns the URL of the next page.
+
+=head2 last_url
+
+Returns the URL of the last page.
+
+=head2 page_url( $page )
+
+Returns the URL of given page.
+
 =head2 BUILD
 
 Private. It casts the magic when building the object.
 
-
 =head1 AUTHOR
 
 Blabos de Blebe, C<< <blabos at cpan.org> >>
 
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -261,14 +335,12 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Paginator-Lite>.
 I will be notified, and then you'll automatically be notified of progress
 on your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Paginator::Lite
 
-
 You can also look for information at:
 
 =over 4
@@ -291,12 +363,6 @@ L<http://search.cpan.org/dist/Paginator-Lite/>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-Estante Virtual L<http://estantevirtual.com.br>
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2012 Blabos de Blebe.
@@ -307,4 +373,15 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information. 
 
+=head1 AUTHOR
+
+Blabos de Blebe <blabos@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Blabos de Blebe.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
